// $Id$
//
// Copyright (C) 2010
//     Stefan Bund <info@j32.de>

/** \file
    \brief InternalNetworkAccessManager public header */

#ifndef HH_PyKit_Publisher_
#define HH_PyKit_Publisher_ 1

// Custom includes
#include <QNetworkAccessManager>
#include <QNetworkRequest>
#include <QNetworkReply>
#include <QBuffer>
#include <boost/noncopyable.hpp>

//#include "Publisher.mpp"
///////////////////////////////hh.p////////////////////////////////////////

namespace pykit {

    namespace detail { class InternalServerReply; }

    class Request
    {
    public:
        void write(std::string const & data);
        void reset();

        void setContentType(std::string const & contentType);
        void setLocation(std::string const & location);

        QUrl url() const;

    private:
        Request(detail::InternalServerReply & reply);

        detail::InternalServerReply & reply_;

        friend class detail::InternalServerReply;
    };

    class Publisher
        : boost::noncopyable
    {
    public:
        virtual ~Publisher() {}
        virtual void publish(Request & request) = 0;
    };

    class InternalNetworkAccessManager
        : public QNetworkAccessManager
    {
        Q_OBJECT;
    public:
        InternalNetworkAccessManager(QNetworkAccessManager * manager, QObject * parent,
                                     Publisher * publisher);

        QNetworkReply * createRequest(Operation operation, QNetworkRequest const & request,
                                      QIODevice * device);

    private:
        Publisher * publisher_;
    };

}

///////////////////////////////hh.e////////////////////////////////////////
//#include "Publisher.cci"
//#include "Publisher.ct"
//#include "Publisher.cti"
#endif


// Local Variables:
// mode: c++
// fill-column: 100
// comment-column: 40
// c-file-style: "j32"
// indent-tabs-mode: nil
// ispell-local-dictionary: "american"
// compile-command: "scons -U"
// End:
